==> meta-0.1.0-20170515.000841-3.jar: nodejs.out/cljs_deps.js <==
goog.addDependency("base.js", ['goog'], []);
goog.addDependency("../cljs/core.js", ['cljs.core'], []);
goog.addDependency("../A7C7D08.js", ['cljs.nodejs'], []);
goog.addDependency("../feathers/core.js", ['feathers.core'], []);
goog.addDependency("../feathers/hooks.js", ['feathers.hooks'], []);
goog.addDependency("../feathers/memory.js", ['feathers.memory'], []);
goog.addDependency("../feathers/favicon.js", ['feathers.favicon'], []);
goog.addDependency("../feathers/socketio.js", ['feathers.socketio'], []);
goog.addDependency("../feathers/compression.js", ['feathers.compression'], []);
goog.addDependency("../feathers/cors.js", ['feathers.cors'], []);
goog.addDependency("../feathers/rest.js", ['feathers.rest'], []);
goog.addDependency("../feathers/body_parser.js", ['feathers.body_parser'], []);
goog.addDependency("../feathers/authentication.js", ['feathers.authentication'], []);
goog.addDependency("../feathers/configuration.js", ['feathers.configuration'], []);
goog.addDependency("../feathers/express.js", ['feathers.express'], []);
goog.addDependency("../feathers/app.js", ['feathers.app'], []);
goog.addDependency("../meta/services.js", ['meta.services'], []);
goog.addDependency("../meta/services/hooks.js", ['meta.services.hooks'], []);
goog.addDependency("../meta/services/users.js", ['meta.services.users'], []);
goog.addDependency("../meta/server/services.js", ['meta.server.services'], []);
goog.addDependency("../meta/server.js", ['meta.server'], []);
goog.addDependency("../app/services.js", ['app.services'], []);
goog.addDependency("../app/server.js", ['app.server'], []);
goog.addDependency("../boot/cljs/main8933.js", ['boot.cljs.main8933'], []);
goog.addDependency("../5A311FF.js", ['cljs.nodejscli'], []);

==> meta-0.1.0-20170516.180826-4.jar: nodejs.out/cljs_deps.js <==
goog.addDependency("base.js", ['goog'], []);
goog.addDependency("../cljs/core.js", ['cljs.core'], []);
goog.addDependency("../1F04940.js", ['cljs.nodejs'], []);
goog.addDependency("../feathers/core.js", ['feathers.core'], []);
goog.addDependency("../feathers/hooks.js", ['feathers.hooks'], []);
goog.addDependency("../feathers/memory.js", ['feathers.memory'], []);
goog.addDependency("../feathers/favicon.js", ['feathers.favicon'], []);
goog.addDependency("../feathers/socketio.js", ['feathers.socketio'], []);
goog.addDependency("../feathers/compression.js", ['feathers.compression'], []);
goog.addDependency("../feathers/cors.js", ['feathers.cors'], []);
goog.addDependency("../feathers/rest.js", ['feathers.rest'], []);
goog.addDependency("../feathers/body_parser.js", ['feathers.body_parser'], []);
goog.addDependency("../feathers/authentication.js", ['feathers.authentication'], []);
goog.addDependency("../feathers/configuration.js", ['feathers.configuration'], []);
goog.addDependency("../feathers/express.js", ['feathers.express'], []);
goog.addDependency("../feathers/app.js", ['feathers.app'], []);
goog.addDependency("../meta/services.js", ['meta.services'], []);
goog.addDependency("../meta/services/hooks.js", ['meta.services.hooks'], []);
goog.addDependency("../meta/services/users.js", ['meta.services.users'], []);
goog.addDependency("../meta/server/services.js", ['meta.server.services'], []);
goog.addDependency("../meta/server.js", ['meta.server'], []);
goog.addDependency("../app/services.js", ['app.services'], []);
goog.addDependency("../app/server.js", ['app.server'], []);
goog.addDependency("../boot/cljs/main8935.js", ['boot.cljs.main8935'], []);
goog.addDependency("../5A311FF.js", ['cljs.nodejscli'], []);
